@@ -15,8 +15,7 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(KPMCORE_DEVICE_H)
-
+#ifndef KPMCORE_DEVICE_H
 #define KPMCORE_DEVICE_H
 
 #include "util/libpartitionmanagerexport.h"
@@ -24,10 +23,13 @@
 #include <QString>
 #include <QObject>
 
+#include <memory>
+
 class PartitionTable;
 class CreatePartitionTableOperation;
 class CoreBackend;
 class SmartStatus;
+class DevicePrivate;
 
 /** A device description.
 
@@ -48,96 +50,66 @@ class LIBKPMCORE_EXPORT Device : public QObject
     friend class CoreBackend;
 
 public:
-    enum Type {
-        Disk_Device = 0,
-        LVM_Device  = 1, /* VG */
-        RAID_Device = 2, /* software RAID device */
-        Unknown_Device = 4
+    enum class Type {
+        Unknown_Device,
+        Disk_Device,
+        LVM_Device, /* VG */
+        SoftwareRAID_Device, /* software RAID device, i.e. mdraid */
+        FakeRAID_Device, /* fake RAID device, i.e. dmraid */
     };
 
-protected:
-    explicit Device(const QString& name, const QString& deviceNode, const qint64 logicalSize, const qint64 totalLogical, const QString& iconName = QString(), Device::Type type = Device::Disk_Device);
+    explicit Device(std::shared_ptr<DevicePrivate> d_ptr, const QString& name, const QString& deviceNode, const qint64 logicalSectorSize, const qint64 totalLogicalSectors, const QString& iconName = QString(), Device::Type type = Device::Type::Disk_Device);
 
 public:
     explicit Device(const Device& other);
     virtual ~Device();
 
-public:
     virtual bool operator==(const Device& other) const;
     virtual bool operator!=(const Device& other) const;
 
-    virtual QString& name() {
-        return m_Name;    /**< @return the Device's name, usually some manufacturer string */
-    }
+    /**< @return the Device's name, usually some manufacturer string */
+    virtual QString& name();
+    virtual const QString& name() const;
 
-    virtual const QString& name() const {
-        return m_Name;    /**< @return the Device's name, usually some manufacturer string */
-    }
+    /**< @return the Device's node, for example "/dev/sda" */
+    virtual const QString& deviceNode() const;
 
-    virtual const QString& deviceNode() const {
-        return m_DeviceNode;    /**< @return the Device's node, for example "/dev/sda" */
-    }
+    /**< @return the logical sector size the Device uses (would be extent size for e.g. LVM devices) */
+    virtual qint64 logicalSize() const;
 
-    virtual PartitionTable* partitionTable() {
-        return m_PartitionTable;    /**< @return the Device's PartitionTable */
-    }
+    /**< @return the total number of logical sectors on the device */
+    virtual qint64 totalLogical() const;
 
-    virtual const PartitionTable* partitionTable() const {
-        return m_PartitionTable;    /**< @return the Device's PartitionTable */
-    }
-
-    virtual qint64 capacity() const { /**< @return the Device's capacity in bytes */
-        return logicalSize() * totalLogical();
-    }
-
-    virtual void setIconName(const QString& name) {
-        m_IconName = name;
-    }
-
-    virtual const QString& iconName() const {
-        return m_IconName;    /**< @return suggested icon name for this Device */
-    }
-
-    virtual SmartStatus& smartStatus() {
-        return *m_SmartStatus;
-    }
-
-    virtual const SmartStatus& smartStatus() const {
-        return *m_SmartStatus;
-    }
+    /**< @return the Device's PartitionTable */
+    virtual PartitionTable* partitionTable();
+    virtual const PartitionTable* partitionTable() const;
 
     /**
      * Change the description of the partition table for different one.
      * The device itself is not changed; use CreatePartitionTableOperation
      * for that. The Device instance becomes the owner of @p ptable .
      */
-    virtual void setPartitionTable(PartitionTable* ptable) {
-        m_PartitionTable = ptable;
+    virtual void setPartitionTable(PartitionTable* ptable);
+
+    virtual qint64 capacity() const { /**< @return the Device's capacity in bytes */
+        return logicalSize() * totalLogical();
     }
 
-    virtual qint64 logicalSize() const {
-        return m_LogicalSize;
-    }
+    /**< @return suggested icon name for this Device */
+    virtual const QString& iconName() const;
 
-    virtual qint64 totalLogical() const {
-        return m_TotalLogical;
-    }
+    /**< @param name set the new Icon for this Device */
+    virtual void setIconName(const QString& name);
 
-    virtual Device::Type type() const {
-        return m_Type;
-    }
+    virtual SmartStatus& smartStatus();
+    virtual const SmartStatus& smartStatus() const;
+
+    virtual Device::Type type() const;
 
     virtual QString prettyName() const;
 
 protected:
-    QString m_Name;
-    QString m_DeviceNode;
-    qint64  m_LogicalSize;
-    qint64  m_TotalLogical;
-    PartitionTable* m_PartitionTable;
-    QString m_IconName;
-    SmartStatus* m_SmartStatus;
-    Device::Type m_Type;
+    std::shared_ptr<DevicePrivate> d;
 };
 
 #endif
