@@ -14,6 +14,7 @@
  *  You should have received a copy of the GNU General Public License    *
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
+
 #include "fs/fat32.h"
 
 #include "util/externalcommand.h"
@@ -26,18 +27,18 @@
 namespace FS
 {
 fat32::fat32(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label) :
-    fat16(firstsector, lastsector, sectorsused, label, FileSystem::Fat32)
+    fat16(firstsector, lastsector, sectorsused, label, FileSystem::Type::Fat32)
 {
 }
 
 qint64 fat32::minCapacity() const
 {
-    return 32 * Capacity::unitFactor(Capacity::Byte, Capacity::MiB);
+    return 32 * Capacity::unitFactor(Capacity::Unit::Byte, Capacity::Unit::MiB);
 }
 
 qint64 fat32::maxCapacity() const
 {
-    return 16 * Capacity::unitFactor(Capacity::Byte, Capacity::TiB) - Capacity::unitFactor(Capacity::Byte, Capacity::MiB);
+    return 16 * Capacity::unitFactor(Capacity::Unit::Byte, Capacity::Unit::TiB) - Capacity::unitFactor(Capacity::Unit::Byte, Capacity::Unit::MiB);
 }
 
 bool fat32::create(Report& report, const QString& deviceNode)
@@ -48,7 +49,8 @@ bool fat32::create(Report& report, const QString& deviceNode)
 
 bool fat32::updateUUID(Report& report, const QString& deviceNode) const
 {
-    qint64 t = time(nullptr);
+    // HACK: replace this hack with fatlabel "-i" (dosfstools 4.2)
+    long int t = time(nullptr);
 
     char uuid[4];
     for (auto &u : uuid) {
@@ -56,15 +58,7 @@ bool fat32::updateUUID(Report& report, const QString& deviceNode) const
         t >>= 8;
     }
 
-    // HACK: replace this hack with fatlabel "-i" (dosfstools 4.2)
-    ExternalCommand cmd(report, QStringLiteral("dd"), { QStringLiteral("of=") + deviceNode, QStringLiteral("bs=1"), QStringLiteral("count=4"), QStringLiteral("seek=67") });
-
-    if (!cmd.start())
-        return false;
-
-    if (cmd.write(uuid, sizeof(uuid)) != sizeof(uuid))
-        return false;
-
-    return cmd.waitFor(-1);
+    ExternalCommand cmd;
+    return cmd.writeData(report, QByteArray(uuid, sizeof(uuid)), deviceNode, 67);
 }
 }
