@@ -16,15 +16,15 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(RESIZEOPERATION__H)
+#if !defined(KPMCORE_RESIZEOPERATION_H)
 
-#define RESIZEOPERATION__H
+#define KPMCORE_RESIZEOPERATION_H
 
-#include "../util/libpartitionmanagerexport.h"
+#include "util/libpartitionmanagerexport.h"
 
-#include "../ops/operation.h"
+#include "ops/operation.h"
 
-#include "../core/partition.h"
+#include "core/partition.h"
 
 #include <QString>
 
@@ -52,7 +52,6 @@ class LIBKPMCORE_EXPORT ResizeOperation : public Operation
 {
     friend class OperationStack;
 
-    Q_OBJECT
     Q_DISABLE_COPY(ResizeOperation)
 
 protected:
@@ -75,16 +74,16 @@ public:
     ResizeOperation(Device& d, Partition& p, qint64 newfirst, qint64 newlast);
 
 public:
-    QString iconName() const {
+    QString iconName() const override {
         return QStringLiteral("arrow-right-double");
     }
-    QString description() const;
-    bool execute(Report& parent);
-    void preview();
-    void undo();
+    QString description() const override;
+    bool execute(Report& parent) override;
+    void preview() override;
+    void undo() override;
 
-    virtual bool targets(const Device& d) const;
-    virtual bool targets(const Partition& p) const;
+    bool targets(const Device& d) const override;
+    bool targets(const Partition& p) const override;
 
     static bool canGrow(const Partition* p);
     static bool canShrink(const Partition* p);
@@ -159,6 +158,9 @@ protected:
         return m_CheckResizedJob;
     }
 
+private:
+    static bool isLVMPVinNewlyVG(const Partition* p);
+
 private:
     Device& m_TargetDevice;
     Partition& m_Partition;
