@@ -16,9 +16,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(SETFILESYSTEMLABELOPERATION__H)
+#if !defined(KPMCORE_SETFILESYSTEMLABELOPERATION_H)
 
-#define SETFILESYSTEMLABELOPERATION__H
+#define KPMCORE_SETFILESYSTEMLABELOPERATION_H
 
 #include "util/libpartitionmanagerexport.h"
 
